%define _disable_ld_no_undefined 1

%define shortname indi


Summary:        Library to control astronomical devices
Name:           indilib
Version:        2.1.3
Release:        %mkrel 1
License:        LGPLv2
Group:          System/Libraries
Url:            https://www.indilib.org/
Source0:        https://github.com/indilib/indi/archive/v%{version}/%{shortname}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  fli-devel
BuildRequires:  nova-devel
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libusb)
BuildRequires:  pkgconfig(cfitsio) >= 3.090
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(libxisf)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libev)

Provides:       %{shortname} = %{version}-%{release}

%description
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

%files
%doc AUTHORS ChangeLog README* NEWS
%{_bindir}/*
%{_datadir}/%{shortname}/
%{_libdir}/%{shortname}/
%{_udevrulesdir}/80-*.rules
%{_udevrulesdir}/99-*.rules

#--------------------------------------------------------------------

%define major   2
%define libname %mklibname indiclient %{major}

%package -n     %{libname}
Summary:        Indi Client library files for INDI
Group:          System/Libraries

Obsoletes:      %{_lib}indi2 < 2.0.8-2

%description -n %{libname}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indiclient library files of indilib.

%files -n %{libname}
%{_libdir}/libindiclient.so.%{major}{,.*}

#--------------------------------------------------------------------

%define libname_alignment %mklibname indialignmentdriver %{major}

%package -n     %{libname_alignment}
Summary:        Indi Alignment Driver library files for INDI
Group:          System/Libraries

%description -n %{libname_alignment}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indiAlignmentDriver library files of indilib.

%files -n %{libname_alignment}
%{_libdir}/libindiAlignmentDriver.so.%{major}{,.*}

#--------------------------------------------------------------------

%define libname_qt %mklibname indiclientqt %{major}

%package -n     %{libname_qt}
Summary:        Indi Client Qt library files for INDI
Group:          System/Libraries

%description -n %{libname_qt}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indiclientqt library files of indilib.

%files -n %{libname_qt}
%{_libdir}/libindiclientqt.so.%{major}{,.*}

#--------------------------------------------------------------------

%define libname_driver %mklibname indidriver %{major}

%package -n     %{libname_driver}
Summary:        Indi Driver library files for INDI
Group:          System/Libraries

%description -n %{libname_driver}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indidriver library files of indilib.

%files -n %{libname_driver}
%{_libdir}/libindidriver.so.%{major}{,.*}

#--------------------------------------------------------------------

%define libname_lx200 %mklibname indilx200_ %{major}

%package -n     %{libname_lx200}
Summary:        Indi lx200 library files for INDI
Group:          System/Libraries

%description -n %{libname_lx200}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains indilx200 library files of indilib.

%files -n %{libname_lx200}
%{_libdir}/libindilx200.so.%{major}{,.*}

#--------------------------------------------------------------------

%define develname %mklibname %{shortname} -d

%package -n     %{develname}
Summary:        INDI development files
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libname_alignment} = %{version}-%{release}
Requires:       %{libname_qt} = %{version}-%{release}
Requires:       %{libname_driver} = %{version}-%{release}
Requires:       %{libname_lx200} = %{version}-%{release}
Provides:       indi-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains files needed to build applications using indilib.

%files -n %{develname}
%doc AUTHORS ChangeLog README* NEWS
%{_libdir}/*.so
%{_libdir}/pkgconfig/libindi.pc
%{_includedir}/libindi/

#--------------------------------------------------------------------
# (lm) libindiclient is built as static only
# libindiclient BR by kstars

%define staticname %mklibname indiclient -s -d

%package -n     %{staticname}
Summary:        INDI indiclient static development file
Group:          Development/C
Requires:       %{develname} = %{version}-%{release}
Provides:       indiclient-static-devel = %{version}-%{release}

%description -n %{staticname}
INDI is an instrument neutral distributed interface control protocol
that aims to provide backend driver support and automation for a wide
range of Astronomical devices (telescopes, focusers, CCDs..etc).

This package contains libindiclient static file needed to build applications
using indiclient.

%files -n %{staticname}
%{_libdir}/libindiclient.a

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n %{shortname}-%{version}

%build
# This package tries to mix and match PIE and PIC which is wrong and will
# trigger link errors when LTO is enabled.
# Disable LTO
%define _lto_cflags %{nil}

%cmake  \
	-DUDEVRULES_INSTALL_DIR=%{_udevrulesdir} \
	-DINDI_BUILD_QT5_CLIENT=ON \
	-DLIBEV_INCLUDE_DIR=%{_includedir}/libev
%cmake_build

%install
%cmake_install

find %{buildroot} \( -name "*.a" ! -name "libindiclient.a" \) -delete


%changelog
* Tue Apr 08 2025 daviddavid <daviddavid> 2.1.3-1.mga10
+ Revision: 2174205
- new version: 2.1.3

* Wed Feb 12 2025 daviddavid <daviddavid> 2.1.2-1.mga10
+ Revision: 2148221
- new version: 2.1.2

* Sat Dec 07 2024 daviddavid <daviddavid> 2.1.1-1.mga10
+ Revision: 2122467
- new version: 2.1.1

* Tue Nov 12 2024 daviddavid <daviddavid> 2.1.0-1.mga10
+ Revision: 2114605
- new version: 2.1.0

* Sun Aug 04 2024 daviddavid <daviddavid> 2.0.9-1.mga10
+ Revision: 2083595
- new version: 2.0.9
- split out all libraries in their own sub-pkgs

* Mon Jun 03 2024 daviddavid <daviddavid> 2.0.8-1.mga10
+ Revision: 2069553
- new version: 2.0.8

* Wed Apr 10 2024 daviddavid <daviddavid> 2.0.7-1.mga10
+ Revision: 2056410
- new version: 2.0.7

* Fri Dec 29 2023 daviddavid <daviddavid> 2.0.5-1.mga10
+ Revision: 2023581
- new version: 2.0.5

* Mon Apr 10 2023 daviddavid <daviddavid> 2.0.1-1.mga9
+ Revision: 1951900
- new version: 2.0.1
- now libmajor is 2
- new libxisf dependency

* Sat Feb 25 2023 daviddavid <daviddavid> 1.9.9-4.mga9
+ Revision: 1945309
- rebuild with fixed cmake libdir path (update install stage)

* Fri Dec 30 2022 daviddavid <daviddavid> 1.9.9-3.mga9
+ Revision: 1928029
- rebuild for gsl 2.7.1 on armv7

* Thu Dec 29 2022 daviddavid <daviddavid> 1.9.9-2.mga9
+ Revision: 1927509
- rebuild for new gsl 2.7.1

* Sun Dec 04 2022 daviddavid <daviddavid> 1.9.9-1.mga9
+ Revision: 1917502
- new version: 1.9.9
- rebuild for new cfitsio 4.2.0

* Fri Aug 26 2022 eatdirt <eatdirt> 1.9.7-1.mga9
+ Revision: 1880538
- Update to version 1.9.7

* Sun Apr 03 2022 umeabot <umeabot> 1.9.2-2.mga9
+ Revision: 1842691
- Mageia 9 Mass Rebuild

* Sun Oct 31 2021 eatdirt <eatdirt> 1.9.2-1.mga9
+ Revision: 1753375
- Upgrade to version 1.9.2

* Wed Dec 16 2020 umeabot <umeabot> 1.8.5-3.mga8
+ Revision: 1658576
- Rebuild for new Qt5

* Thu Jul 23 2020 daviddavid <daviddavid> 1.8.5-2.mga8
+ Revision: 1608160
- rebuild for new cfitsio 3.480

* Fri Jul 10 2020 daviddavid <daviddavid> 1.8.5-1.mga8
+ Revision: 1604002
- new version: 1.8.5
- remove merged upstream patch

* Fri Mar 27 2020 daviddavid <daviddavid> 1.8.4-4.mga8
+ Revision: 1560907
- rebuild for new cfitsio 3.470

* Mon Feb 24 2020 daviddavid <daviddavid> 1.8.4-3.mga8
+ Revision: 1549777
- add upstream patch to disable stime on arm

* Fri Feb 21 2020 umeabot <umeabot> 1.8.4-2.mga8
+ Revision: 1547828
- Mageia 8 Mass Rebuild

* Mon Feb 10 2020 daviddavid <daviddavid> 1.8.4-1.mga8
+ Revision: 1488450
- new version: 1.8.4
+ wally <wally>
- build with new cmake macros

* Tue Aug 27 2019 daviddavid <daviddavid> 1.7.8-2.mga8
+ Revision: 1433761
- rebuild for new gsl 2.6

* Tue May 21 2019 eatdirt <eatdirt> 1.7.8-1.mga7
+ Revision: 1398779
- Update to version 1.7.8

* Sun Jan 06 2019 daviddavid <daviddavid> 1.7.5-1.mga7
+ Revision: 1350132
- new version: 1.7.5
- enable Qt5 client

* Sun Sep 23 2018 umeabot <umeabot> 1.7.4-2.mga7
+ Revision: 1298297
- Mageia 7 Mass Rebuild

* Fri Jul 27 2018 daviddavid <daviddavid> 1.7.4-1.mga7
+ Revision: 1245507
- new version: 1.7.4

* Sun May 13 2018 daviddavid <daviddavid> 1.6.2-2.mga7
+ Revision: 1228768
- rebuild for new cfitsio 3.450

* Tue Apr 03 2018 kekepower <kekepower> 1.6.2-1.mga7
+ Revision: 1214826
- Update to version 1.6.2

* Wed Dec 27 2017 wally <wally> 1.3.1-2.mga7
+ Revision: 1185644
- rebuild for new gsl

* Tue Nov 22 2016 eatdirt <eatdirt> 1.3.1-1.mga6
+ Revision: 1068757
- Upgrade indilib to 1.3.1

* Wed Mar 09 2016 eatdirt <eatdirt> 1.2.0-1.mga6
+ Revision: 988569
- Upgrade to version 1.2.0

* Sun Jan 03 2016 luigiwalser <luigiwalser> 0.9.8.1-6.mga6
+ Revision: 919006
- rebuild for gsl

* Wed Oct 15 2014 umeabot <umeabot> 0.9.8.1-5.mga5
+ Revision: 739055
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.8.1-4.mga5
+ Revision: 680506
- Mageia 5 Mass Rebuild

* Mon Jul 14 2014 lmenut <lmenut> 0.9.8.1-3.mga5
+ Revision: 651829
- restore libindiclient static only library in indiclient-static-devel

* Sat Jul 05 2014 pterjan <pterjan> 0.9.8.1-2.mga5
+ Revision: 643689
- Replace libusb*-devel BuildRequires by better ones

* Wed Jul 02 2014 wally <wally> 0.9.8.1-1.mga5
+ Revision: 642379
- new version 0.8.9.1
- drop static libs

* Thu Feb 27 2014 eatdirt <eatdirt> 0.9.6-7.mga5
+ Revision: 597698
- Rebuild for new cfitsio

* Sat Oct 19 2013 umeabot <umeabot> 0.9.6-6.mga4
+ Revision: 530063
- Mageia 4 Mass Rebuild

* Tue Jul 16 2013 eatdirt <eatdirt> 0.9.6-5.mga4
+ Revision: 454939
- Rebuild for cfitsio 3.350
+ fwang <fwang>
- there is no boost req

* Wed Jul 10 2013 fwang <fwang> 0.9.6-4.mga4
+ Revision: 452327
- rebuild for new boost

* Wed Jan 16 2013 fwang <fwang> 0.9.6-3.mga3
+ Revision: 388523
- correct udev rules dir

* Sat Jan 12 2013 umeabot <umeabot> 0.9.6-2.mga3
+ Revision: 354397
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 22 2012 mikala <mikala> 0.9.6-1.mga3
+ Revision: 320435
- Update tarball to 0.9.6
- Build with no_undefined
- Minor clean spec

* Sun Sep 02 2012 fedya <fedya> 0.9.5-1.mga3
+ Revision: 287429
- version update 0.9.5

* Fri Jun 08 2012 fwang <fwang> 0.9.1-1.mga3
+ Revision: 257506
- new version 0.9.1
- drop merged pathes

* Sat Jan 14 2012 fwang <fwang> 0.9-1.mga2
+ Revision: 195892
- new version 0.9

* Mon Jun 27 2011 dmorgan <dmorgan> 0.8-1.mga2
+ Revision: 114962
- add boost-devel as buildrequires
- New version 0.8
  Rediff P1
  Fix package layout

* Sat Jan 22 2011 ahmad <ahmad> 0.6.2-1.mga1
+ Revision: 33224
- imported package indilib


* Sat Aug 21 2010 Funda Wang <fwang@mandriva.org> 0.6.2-1mdv2011.0
+ Revision: 571679
- New version 0.6.2

* Sat Aug 21 2010 Funda Wang <fwang@mandriva.org> 0.6-4mdv2011.0
+ Revision: 571653
- adopt to new prefix of cfitsio headers

* Sat Aug 21 2010 Funda Wang <fwang@mandriva.org> 0.6-3mdv2011.0
+ Revision: 571618
- rebuild for new cfitsio

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0.6-2mdv2010.1
+ Revision: 522923
- rebuilt for 2010.1

* Wed May 20 2009 Funda Wang <fwang@mandriva.org> 0.6-1mdv2010.0
+ Revision: 377904
- fix str fmt

* Tue Nov 25 2008 Funda Wang <fwang@mandriva.org> 0.6-1mdv2009.1
+ Revision: 306522
- 0.6 final

* Sun Nov 16 2008 Funda Wang <fwang@mandriva.org> 0.6-0.190.4mdv2009.1
+ Revision: 303755
- add requires on libpackage

* Sun Nov 16 2008 Funda Wang <fwang@mandriva.org> 0.6-0.190.3mdv2009.1
+ Revision: 303750
- don't obsolete itself

* Sun Nov 16 2008 Funda Wang <fwang@mandriva.org> 0.6-0.190.2mdv2009.1
+ Revision: 303745
- ajudst LIB_SUFFIX
- New snapshot for kdeedu4
- BR cfitsio
- New verison 0.5
- add libname

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 0.3-5mdv2009.0
+ Revision: 264685
- rebuild early 2009.0 package (before pixel changes)

* Sun Jun 08 2008 Helio Chissini de Castro <helio@mandriva.com> 0.3-4mdv2009.0
+ Revision: 216943
- Submit missing cooker package

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag

* Tue Dec 18 2007 Thierry Vignaud <tv@mandriva.org> 0.3-2mdv2008.1
+ Revision: 132210
- BR zlib-devel
- kill re-definition of %%buildroot on Pixel's request
- import indilib


* Sun Apr 30 2006 Emmanuel Blindauer <blindauer@mandriva.org> 0.3-2mdk
- fix ExclusiveArch

* Sat Dec 31 2005 Olivier Thauvin <nanardon@mandriva.org> 0.3-1mdk
- 0.3

* Thu Sep 02 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.2-2mdk
- add provides

* Wed Sep 01 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.2-1mdk
- First mdk contrib 
